Item

Enum Item 

enum Item {
    Plain {
        text: String,
        span: Option<Span>,
    },
    Complex {
        surround: Surround,
        text: String,
        te_span: Span,
    },
}
Entry in a ${paste ...} or ${CASE ...}

te_span is the span of this item entry in the template. It is used for error reporting if we can’t cope with this entry (for example, if we have multiple nontrivial entries.)

Variants



Plain

Fields

text: String
span: Option<Span>


Complex

Fields

surround: Surround
text: String
te_span: Span