pub struct AtomForReport {
text: String,
span: Span,
}Expand description
One spanned input element, for use when reporting bad ident errors
We call this an “atom”; in nested pastes, the atoms are the original input items.
Fields
text: Stringspan: SpanTrait Implementations
Sourceimpl Clone for AtomForReport
impl Clone for AtomForReport
Sourcefn clone(&self) -> AtomForReport
fn clone(&self) -> AtomForReport
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for AtomForReport
impl RefUnwindSafe for AtomForReport
impl !Send for AtomForReport
impl !Sync for AtomForReport
impl Unpin for AtomForReport
impl UnwindSafe for AtomForReport