pub struct ChangeCaseOkIn<O: SubstParseContext> {
pub not_in_bool: O::NotInBool,
paste_context_checked: (),
}Expand description
Token that an associated ChangeCase has been checked for legal context
Really this ought to be a field in each variant of ChangeCase<O>
but that would make lots of pointless generics.
The keyword-specific part of the check is just an avoidance of user error, anyway.
Fields
not_in_bool: O::NotInBoolpaste_context_checked: ()Implementations
Sourceimpl<O: SubstParseContext> ChangeCaseOkIn<O>
impl<O: SubstParseContext> ChangeCaseOkIn<O>
pub fn new_checked(case: ChangeCase, span: Span) -> Result<Self>