TokenPastesAsIdent

Struct TokenPastesAsIdent 

pub struct TokenPastesAsIdent<T>(pub T);
For use with ExpansionOutput.push_identfrag_toks

Will then write out T as its tokens. In identifier pasting, converts the tokens to a string first (so they had better be identifiers, or ident fragments).

Tuple Fields

0: T