pub struct Items {
span: Span,
items: Vec<Item>,
errors: Vec<Error>,
atoms: Vec<AtomForReport>,
}Expand description
Accumulator for things to be pasted
Implements ExpansionOutput and SubstParseContext:
i.e., it corresponds to the lexical context for a ${paste },
and collects the identifier fragments being pasted.
Fields
span: SpanError reporting for bad identifiers, and also the output span
items: Vec<Item>errors: Vec<Error>atoms: Vec<AtomForReport>Implementations
Sourceimpl Items
impl Items
fn append_atom(&mut self, item: Item)
fn append_item_raw(&mut self, item: Item)
Sourcefn append_plain<V: Display>(&mut self, span: Span, v: V)
fn append_plain<V: Display>(&mut self, span: Span, v: V)
Append a plain entry from something Display
Like ExpansionOutput::append_display but doesn’t need Spanned
pub fn append_fixed_string(&mut self, text: &'static str)
Sourcepub fn assemble(
self,
out: &mut impl ExpansionOutput,
change_case: Option<ChangeCase>,
) -> Result<()>
pub fn assemble( self, out: &mut impl ExpansionOutput, change_case: Option<ChangeCase>, ) -> Result<()>
Combine the accumulated pieces and append them to out
Calls
append_idpath
if the content contained a nontrivial expansion
or
append_identfrag_toks
otherwise.
Sourcefn assemble_inner(
tspan: Span,
items: Vec<Item>,
change_case: Option<ChangeCase>,
atoms: Vec<AtomForReport>,
) -> Result<AssemblyInstruction>
fn assemble_inner( tspan: Span, items: Vec<Item>, change_case: Option<ChangeCase>, atoms: Vec<AtomForReport>, ) -> Result<AssemblyInstruction>
Combine the accumulated pieces and say what to do
Inner, non-monomorphised, function for Items::assemble.
Returns Right with values to pass to
append_idpath
or
Left with the value to pass to
append_identfrag_toks.