pub struct TokenPastesAsIdent<T>(pub T);Expand description
For use with ExpansionOutput.push_identfrag_toks
Will then write out T as its tokens.
In identifier pasting, converts the tokens to a string first
(so they had better be identifiers, or ident fragments).
Tuple Fields
0: TTrait Implementations
Sourceimpl<T: ToTokens> IdentFrag for TokenPastesAsIdent<T>
impl<T: ToTokens> IdentFrag for TokenPastesAsIdent<T>
type BadIdent = IdentFragInfallible
Sourcefn frag_to_tokens(&self, out: &mut TokenStream) -> Result<(), Self::BadIdent>
fn frag_to_tokens(&self, out: &mut TokenStream) -> Result<(), Self::BadIdent>
(Try to) convert to tokens (ie, real
Ident) Read moreSourcefn note_atoms(&self, out: &mut Vec<AtomForReport>)
fn note_atoms(&self, out: &mut Vec<AtomForReport>)